import setuptools

setuptools.setup(
    name="nerdler_tc",
    version="1.0.0",
    description="Clean text from special characters and blanks",
    author="nerdler_pt",
    author_email="no-reply@nerdler.pt",
    packages=["nerdler_tc"],
    url="https://www.nerdler.pt",
    license="MIT",
    platforms="any"
)